@@ -19,10 +19,10 @@ from simpledate.utils import DebugLog, MRUSortedIterable, OrderedSet, set_kargs_
 
 # Build the various formats used by SimpleDateParser.
 
-RFC_2822 = EMAIL = (invert('(!a!, ?)d! ?b! ?Y! H:M(:S)?(! !Z|! ?z)?'),)
+RFC_2822 = EMAIL = ('(!a!, ?)d! ?b! ?Y! H:M(:S)?(! !Z|! ?z)?',)
 ISO_8601 = YMD = (invert('Y(!-?m(!-?d((! |%T)H!:?M(!:?S(.f)?)?)?)?)?(! !Z|! ?z)?'),)
-MDY = (invert('(m!/d!/)?Y(! H!:M(!:S(.f)?)?)?(! !Z|! ?z)?'),)
-DMY = (invert('(d!/m!/)?Y(! H!:M(!:S(.f)?)?)?(! !Z|! ?z)?'),)
+MDY = ('(m!/d!/)?Y(! H!:M(!:S(.f)?)?)?(! !Z|! ?z)?',)
+DMY = ('(d!/m!/)?Y(! H!:M(!:S(.f)?)?)?(! !Z|! ?z)?',)
 
 DEFAULT_FORMAT = '%Y-%m-%d %H:%M:%S.%f %Z'
 DEFAULT_FORMATS = ISO_8601 + RFC_2822
@@ -671,7 +671,7 @@ class SimpleDateParser(DebugLog):
     '''
 
     def __init__(self, formats=DEFAULT_FORMATS):
-        formats = always_tuple(formats)
+        formats = tuple(map(auto_invert, always_tuple(formats)))
         self._formats = MRUSortedIterable(formats)
 
     def parse(self, date,
@@ -824,7 +824,7 @@ class DateTimeWrapper:
             return '{0}({1!r}, tz={2!r})'.format(self.__class__.__name__, str(self), str(self.__datetime.tzinfo))
 
     def strftime(self, format):
-        return self.__datetime.strftime(format)
+        return self.__datetime.strftime(auto_invert(format))
 
     def __eq__(self, other):
         return isinstance(other, DateTimeWrapper) and self.__datetime == other.datetime and self.__format == other.__format
